Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(132)

Unified Diff: pkg/mqtt/lib/mqtt.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/mdns/bin/mdns-resolve.dart ('k') | pkg/mqtt/lib/src/mqtt_client.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/mqtt/lib/mqtt.dart
diff --git a/pkg/mqtt/lib/mqtt.dart b/pkg/mqtt/lib/mqtt.dart
index 58126a59775cd87fd380d03aa44013553cdbeec8..db32c4d4b877edd43af5683bdfa0ea3644e55f43 100644
--- a/pkg/mqtt/lib/mqtt.dart
+++ b/pkg/mqtt/lib/mqtt.dart
@@ -55,7 +55,7 @@
/// This Dart library depends on the [Paho C
/// library](http://git.eclipse.org/c/paho/org.eclipse.paho.mqtt.c.git/about/).
/// It will load the Paho shared object file (.so file) dynamically at runtime.
/// Therefore the Paho shared object file needs to be copied into the Fletch
/// SDK. Follow these instructions to compile and copy the library:
///
/// 1. Get the Paho source code
@@ -69,13 +69,13 @@
/// $ make
/// ```
///
/// 1. Copy the library to the lib directory Fletch SDK (substitute `<Fletch SDK
/// location>` with the location where you installed the Fletch SDK, e.g.
/// ~/fletch-sdk/)
///
/// ```
/// $ cd org.eclipse.paho.mqtt.c/
-/// $ cp build/output/libpaho-mqtt3c.so <Fletch SDK location>/lib/
+/// $ cp build/output/libpaho-mqtt3c.so <Dartino SDK location>/lib/
///
/// ```
///
@@ -86,7 +86,7 @@
library mqtt;
-import 'dart:fletch';
+import 'dart:dartino';
import 'package:os/os.dart';
import 'package:immutable/immutable.dart';
« no previous file with comments | « pkg/mdns/bin/mdns-resolve.dart ('k') | pkg/mqtt/lib/src/mqtt_client.dart » ('j') | no next file with comments »
@@ -55,7 +55,7 @@
/// library](http://git.eclipse.org/c/paho/org.eclipse.paho.mqtt.c.git/about/).
/// It will load the Paho shared object file (.so file) dynamically at runtime.
-/// Therefore the Paho shared object file needs to be copied into the Fletch
+/// Therefore the Paho shared object file needs to be copied into the Dartino
/// SDK. Follow these instructions to compile and copy the library:
///
@@ -69,13 +69,13 @@
/// ```
///
-/// 1. Copy the library to the lib directory Fletch SDK (substitute `<Fletch SDK
-/// location>` with the location where you installed the Fletch SDK, e.g.
-/// ~/fletch-sdk/)
+/// 1. Copy the library to the lib directory Dartino SDK (substitute `<Dartino SDK
+/// location>` with the location where you installed the Dartino SDK, e.g.
+/// ~/dartino-sdk/)
///
/// ```

Powered by Google App Engine
This is Rietveld 408576698